@@ -1,9 +1,11 @@
 ## initialize!
 
-@muladd function initialize!(nlsolver::NLSolver{<:NLNewton, false},
-        integrator::SciMLBase.DEIntegrator)
-    @unpack dt = integrator
-    @unpack cache = nlsolver
+@muladd function initialize!(
+        nlsolver::NLSolver{<:NLNewton, false},
+        integrator::SciMLBase.DEIntegrator
+    )
+    (; dt) = integrator
+    (; cache) = nlsolver
 
     cache.invγdt = inv(dt * nlsolver.γ)
     cache.tstep = integrator.t + nlsolver.c * dt
@@ -11,28 +13,34 @@
     nothing
 end
 
-@muladd function initialize!(nlsolver::NLSolver{<:NLNewton, true},
-        integrator::SciMLBase.DEIntegrator)
-    @unpack u, uprev, t, dt, opts = integrator
-    @unpack cache = nlsolver
-    @unpack weight = cache
+@muladd function initialize!(
+        nlsolver::NLSolver{<:NLNewton, true},
+        integrator::SciMLBase.DEIntegrator
+    )
+    (; u, uprev, t, dt, opts) = integrator
+    (; cache) = nlsolver
+    (; weight) = cache
 
     cache.invγdt = inv(dt * nlsolver.γ)
     cache.tstep = integrator.t + nlsolver.c * dt
-    calculate_residuals!(weight, fill!(weight, one(eltype(u))), uprev, u,
-        opts.abstol, opts.reltol, opts.internalnorm, t)
+    calculate_residuals!(
+        weight, fill!(weight, one(eltype(u))), uprev, u,
+        opts.abstol, opts.reltol, opts.internalnorm, t
+    )
 
     nothing
 end
 
-function initialize!(nlsolver::NLSolver{<:NonlinearSolveAlg, false},
-        integrator::SciMLBase.DEIntegrator)
-    @unpack uprev, t, p, dt, opts, f = integrator
-    @unpack z, tmp, ztmp, γ, α, iter, cache, method, alg = nlsolver
+function initialize!(
+        nlsolver::NLSolver{<:NonlinearSolveAlg, false},
+        integrator::SciMLBase.DEIntegrator
+    )
+    (; uprev, t, p, dt, opts, f) = integrator
+    (; z, tmp, ztmp, γ, α, iter, cache, method, alg) = nlsolver
     cache.invγdt = inv(dt * nlsolver.γ)
     cache.tstep = integrator.t + nlsolver.c * dt
 
-    @unpack ustep, tstep, k, invγdt = cache
+    (; ustep, tstep, k, invγdt) = cache
     if SciMLBase.has_stats(integrator)
         integrator.stats.nf += cache.cache.stats.nf
         integrator.stats.nnonliniter += cache.cache.stats.nsteps
@@ -45,18 +53,20 @@ function initialize!(nlsolver::NLSolver{<:NonlinearSolveAlg, false},
     end
     new_prob = remake(cache.prob, p = nlp_params, u0 = z)
     cache.cache = init(new_prob, alg.alg)
-    nothing
+    return nothing
 end
 
-function initialize!(nlsolver::NLSolver{<:NonlinearSolveAlg, true},
-        integrator::SciMLBase.DEIntegrator)
-    @unpack uprev, t, p, dt, opts, f = integrator
-    @unpack z, tmp, ztmp, γ, α, iter, cache, method, alg = nlsolver
+function initialize!(
+        nlsolver::NLSolver{<:NonlinearSolveAlg, true},
+        integrator::SciMLBase.DEIntegrator
+    )
+    (; uprev, t, p, dt, opts, f) = integrator
+    (; z, tmp, ztmp, γ, α, iter, cache, method, alg) = nlsolver
 
     cache.invγdt = inv(dt * nlsolver.γ)
     cache.tstep = integrator.t + nlsolver.c * dt
 
-    @unpack ustep, atmp, tstep, k, invγdt = cache
+    (; ustep, atmp, tstep, k, invγdt) = cache
 
     if SciMLBase.has_stats(integrator)
         integrator.stats.nf += cache.cache.stats.nf
@@ -77,32 +87,34 @@ function initialize!(nlsolver::NLSolver{<:NonlinearSolveAlg, true},
             nlstep_data.set_outer_tmp(nlstep_data.nlprob, atmp)
         end
         nlstep_data.nlprob.u0 .= @view z[nlstep_data.u0perm]
-        SciMLBase.reinit!(cache.cache, nlstep_data.nlprob.u0, p=nlstep_data.nlprob.p)
+        SciMLBase.reinit!(cache.cache, nlstep_data.nlprob.u0, p = nlstep_data.nlprob.p)
     else
         if f isa DAEFunction
             nlp_params = (tmp, ztmp, ustep, γ, α, tstep, k, invγdt, p, dt, f)
         else
             nlp_params = (tmp, ustep, γ, α, tstep, k, invγdt, method, p, dt, f)
         end
-        SciMLBase.reinit!(cache.cache, z, p=nlp_params)
+        SciMLBase.reinit!(cache.cache, z, p = nlp_params)
     end
-    nothing
+    return nothing
 end
 
 ## compute_step!
 
 @muladd function compute_step!(nlsolver::NLSolver{<:NonlinearSolveAlg, false}, integrator)
-    @unpack uprev, t, p, dt, opts = integrator
-    @unpack z, tmp, ztmp, γ, α, cache, method = nlsolver
-    @unpack tstep, invγdt = cache
+    (; uprev, t, p, dt, opts) = integrator
+    (; z, tmp, ztmp, γ, α, cache, method) = nlsolver
+    (; tstep, invγdt) = cache
 
     nlcache = nlsolver.cache.cache
     step!(nlcache)
     nlsolver.ztmp = nlcache.u
 
     ustep = compute_ustep(tmp, γ, z, method)
-    atmp = calculate_residuals(nlcache.fu, uprev, ustep, opts.abstol, opts.reltol,
-        opts.internalnorm, t)
+    atmp = calculate_residuals(
+        nlcache.fu, uprev, ustep, opts.abstol, opts.reltol,
+        opts.internalnorm, t
+    )
     ndz = opts.internalnorm(atmp, t)
     #ndz = opts.internalnorm(nlcache.fu, t)
     # NDF and BDF are special because the truncation error is directly
@@ -114,9 +126,9 @@ end
 end
 
 @muladd function compute_step!(nlsolver::NLSolver{<:NonlinearSolveAlg, true}, integrator)
-    @unpack uprev, t, p, dt, opts = integrator
-    @unpack z, tmp, ztmp, γ, α, cache, method = nlsolver
-    @unpack tstep, invγdt, atmp, ustep = cache
+    (; uprev, t, p, dt, opts) = integrator
+    (; z, tmp, ztmp, γ, α, cache, method) = nlsolver
+    (; tstep, invγdt, atmp, ustep) = cache
 
     nlstep_data = integrator.f.nlstep_data
     nlcache = nlsolver.cache.cache
@@ -129,16 +141,20 @@ end
         )
         nlstep_data.nlprobmap(ztmp, nlstepsol)
         ustep = compute_ustep!(ustep, tmp, γ, z, method)
-        calculate_residuals!(@view(atmp[nlstep_data.u0perm]), nlcache.fu, 
-                             @view(uprev[nlstep_data.u0perm]), 
-                             @view(ustep[nlstep_data.u0perm]), opts.abstol, 
-                             opts.reltol, opts.internalnorm, t)
+        calculate_residuals!(
+            @view(atmp[nlstep_data.u0perm]), nlcache.fu,
+            @view(uprev[nlstep_data.u0perm]),
+            @view(ustep[nlstep_data.u0perm]), opts.abstol,
+            opts.reltol, opts.internalnorm, t
+        )
         ndz = opts.internalnorm(atmp, t)
     else
-        @.. broadcast=false ztmp=nlcache.u
+        @.. broadcast = false ztmp = nlcache.u
         ustep = compute_ustep!(ustep, tmp, γ, z, method)
-        calculate_residuals!(atmp, nlcache.fu, uprev, ustep, opts.abstol, opts.reltol,
-                                opts.internalnorm, t)
+        calculate_residuals!(
+            atmp, nlcache.fu, uprev, ustep, opts.abstol, opts.reltol,
+            opts.internalnorm, t
+        )
         ndz = opts.internalnorm(atmp, t)
     end
 
@@ -174,9 +190,9 @@ Equations II, Springer Series in Computational Mathematics. ISBN
 [doi:10.1007/978-3-642-05221-7](https://doi.org/10.1007/978-3-642-05221-7).
 """
 @muladd function compute_step!(nlsolver::NLSolver{<:NLNewton, false}, integrator, γW)
-    @unpack uprev, t, p, dt, opts = integrator
-    @unpack z, tmp, ztmp, γ, α, cache, method = nlsolver
-    @unpack tstep, W, invγdt = cache
+    (; uprev, t, p, dt, opts) = integrator
+    (; z, tmp, ztmp, γ, α, cache, method) = nlsolver
+    (; tstep, W, invγdt) = cache
 
     f = nlsolve_f(integrator)
 
@@ -203,8 +219,10 @@ Equations II, Springer Series in Computational Mathematics. ISBN
         integrator.stats.nsolve += 1
     end
 
-    atmp = calculate_residuals(dz, uprev, ustep, opts.abstol, opts.reltol,
-        opts.internalnorm, t)
+    atmp = calculate_residuals(
+        dz, uprev, ustep, opts.abstol, opts.reltol,
+        opts.internalnorm, t
+    )
     ndz = opts.internalnorm(atmp, t)
     # NDF and BDF are special because the truncation error is directly
     # proportional to the total displacement.
@@ -219,9 +237,9 @@ Equations II, Springer Series in Computational Mathematics. ISBN
 end
 
 @muladd function compute_step!(nlsolver::NLSolver{<:NLNewton, true}, integrator, γW)
-    @unpack uprev, t, p, dt, opts = integrator
-    @unpack z, tmp, ztmp, γ, α, iter, cache, method = nlsolver
-    @unpack W_γdt, ustep, tstep, k, atmp, dz, W, new_W, invγdt, linsolve, weight = cache
+    (; uprev, t, p, dt, opts) = integrator
+    (; z, tmp, ztmp, γ, α, iter, cache, method) = nlsolver
+    (; W_γdt, ustep, tstep, k, atmp, dz, W, new_W, invγdt, linsolve, weight) = cache
 
     f = nlsolve_f(integrator)
     isdae = f isa DAEFunction
@@ -235,7 +253,8 @@ end
         b, ustep = _compute_rhs!(tmp, ztmp, ustep, α, tstep, k, invγdt, p, _uprev, f, z)
     else
         b, ustep = _compute_rhs!(
-            tmp, ztmp, ustep, γ, α, tstep, k, invγdt, method, p, dt, f, z)
+            tmp, ztmp, ustep, γ, α, tstep, k, invγdt, method, p, dt, f, z
+        )
     end
 
     # update W
@@ -253,17 +272,20 @@ end
     end
 
     if is_always_new(nlsolver) || (iter == 1 && new_W)
-        linres = dolinsolve(integrator, linsolve; A = W, b = _vec(b), linu = _vec(dz),
-            reltol = reltol)
+        linres = dolinsolve(
+            integrator, linsolve; A = W, b = _vec(b), linu = _vec(dz),
+            reltol = reltol
+        )
     else
         linres = dolinsolve(
             integrator, linsolve; A = nothing, b = _vec(b), linu = _vec(dz),
-            reltol = reltol)
+            reltol = reltol
+        )
     end
 
     if !SciMLBase.successful_retcode(linres.retcode) &&
-       linres.retcode != SciMLBase.ReturnCode.Default
-        return convert(eltype(atmp,), Inf)
+            linres.retcode != SciMLBase.ReturnCode.Default
+        return convert(eltype(atmp), Inf)
     end
 
     cache.linsolve = linres.cache
@@ -281,8 +303,10 @@ end
     !(W_γdt ≈ γdt) && (rmul!(dz, 2 / (1 + γdt / W_γdt)))
     relax!(dz, nlsolver, integrator, f)
 
-    calculate_residuals!(atmp, dz, uprev, ustep, opts.abstol, opts.reltol,
-        opts.internalnorm, t)
+    calculate_residuals!(
+        atmp, dz, uprev, ustep, opts.abstol, opts.reltol,
+        opts.internalnorm, t
+    )
     ndz = opts.internalnorm(atmp, t)
 
     # NDF and BDF are special because the truncation error is directly
@@ -292,14 +316,14 @@ end
     end
 
     # compute next iterate
-    @.. broadcast=false ztmp=z - dz
+    @.. broadcast = false ztmp = z - dz
 
     ndz
 end
 
 function get_dae_uprev(integrator, uprev)
     # not all predictors are uprev, for other forms of predictors, defined in u₀
-    if isdefined(integrator.cache, :u₀)
+    return if isdefined(integrator.cache, :u₀)
         integrator.cache.u₀
     else
         uprev
@@ -314,7 +338,7 @@ function _compute_rhs(tmp, α, tstep, invγdt, p, uprev, f::TF, z) where {TF <:
 end
 
 function compute_ustep(tmp, γ, z, method)
-    if method === COEFFICIENT_MULTISTEP
+    return if method === COEFFICIENT_MULTISTEP
         z
     else
         @. tmp + γ * z
@@ -327,11 +351,11 @@ function compute_ustep!(ustep, tmp, γ, z, method)
     else
         @.. ustep = tmp + γ * z
     end
-    ustep
+    return ustep
 end
 
-function _compute_rhs(tmp, γ, α, tstep, invγdt, method::MethodType, p, dt, f::F, z) where F
-    mass_matrix = f.mass_matrix
+function _compute_rhs(tmp, γ, α, tstep, invγdt, method::MethodType, p, dt, f::F, z) where {F}
+    mass_matrix = get_mass_matrix(f)
     ustep = compute_ustep(tmp, γ, z, method)
     if method === COEFFICIENT_MULTISTEP
         # tmp = outertmp ./ hγ
@@ -352,26 +376,30 @@ function _compute_rhs(tmp, γ, α, tstep, invγdt, method::MethodType, p, dt, f:
     return ztmp, ustep
 end
 
-function _compute_rhs!(tmp, ztmp, ustep, α, tstep, k,
-        invγdt, p, uprev, f::TF, z) where {TF <: DAEFunction}
-    @.. broadcast=false ztmp=(tmp + α * z) * invγdt
+function _compute_rhs!(
+        tmp, ztmp, ustep, α, tstep, k,
+        invγdt, p, uprev, f::TF, z
+    ) where {TF <: DAEFunction}
+    @.. broadcast = false ztmp = (tmp + α * z) * invγdt
     @.. ustep = uprev + z
     f(k, ztmp, ustep, p, tstep)
     return _vec(k), ustep
 end
 
-function _compute_rhs!(tmp, ztmp, ustep, γ, α, tstep, k,
-        invγdt, method::MethodType, p, dt, f, z)
-    mass_matrix = f.mass_matrix
+function _compute_rhs!(
+        tmp, ztmp, ustep, γ, α, tstep, k,
+        invγdt, method::MethodType, p, dt, f, z
+    )
+    mass_matrix = get_mass_matrix(f)
     ustep = compute_ustep!(ustep, tmp, γ, z, method)
     if method === COEFFICIENT_MULTISTEP
         f(k, z, p, tstep)
         if mass_matrix === I
-            @.. broadcast=false ztmp=tmp + k - (α * invγdt) * z
+            @.. broadcast = false ztmp = tmp + k - (α * invγdt) * z
         else
             update_coefficients!(mass_matrix, ustep, p, tstep)
             mul!(_vec(ztmp), mass_matrix, _vec(z))
-            @.. broadcast=false ztmp=tmp + k - (α * invγdt) * ztmp
+            @.. broadcast = false ztmp = tmp + k - (α * invγdt) * ztmp
         end
     else
         f(k, ustep, p, tstep)
@@ -386,8 +414,10 @@ function _compute_rhs!(tmp, ztmp, ustep, γ, α, tstep, k,
     return _vec(ztmp), ustep
 end
 
-function _compute_rhs!(tmp::Array, ztmp::Array, ustep::Array, α, tstep, k,
-        invγdt, p, uprev, f::TF, z) where {TF <: DAEFunction}
+function _compute_rhs!(
+        tmp::Array, ztmp::Array, ustep::Array, α, tstep, k,
+        invγdt, p, uprev, f::TF, z
+    ) where {TF <: DAEFunction}
     @inbounds @simd ivdep for i in eachindex(z)
         ztmp[i] = (tmp[i] + α * z[i]) * invγdt
     end
@@ -399,9 +429,11 @@ function _compute_rhs!(tmp::Array, ztmp::Array, ustep::Array, α, tstep, k,
     return _vec(k), ustep
 end
 
-function _compute_rhs!(tmp::Array, ztmp::Array, ustep::Array, γ, α, tstep, k,
-        invγdt, method::MethodType, p, dt, f, z)
-    mass_matrix = f.mass_matrix
+function _compute_rhs!(
+        tmp::Array, ztmp::Array, ustep::Array, γ, α, tstep, k,
+        invγdt, method::MethodType, p, dt, f, z
+    )
+    mass_matrix = get_mass_matrix(f)
     ustep = compute_ustep!(ustep, tmp, γ, z, method)
     if method === COEFFICIENT_MULTISTEP
         f(k, z, p, tstep)
@@ -437,46 +469,56 @@ end
 
 ## relax!
 function relax!(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF) where {TF}
-    relax!(dz, nlsolver, integrator, f, relax(nlsolver))
+    return relax!(dz, nlsolver, integrator, f, relax(nlsolver))
 end
 function relax(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF) where {TF}
-    relax(dz, nlsolver, integrator, f, relax(nlsolver))
+    return relax(dz, nlsolver, integrator, f, relax(nlsolver))
 end
-function relax!(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
-        r::Nothing) where {TF}
-        dz
+function relax!(
+        dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
+        r::Nothing
+    ) where {TF}
+    return dz
 end
-function relax!(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
-        r::Number) where {TF}
+function relax!(
+        dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
+        r::Number
+    ) where {TF}
     if !iszero(r)
         rmul!(dz, 1 - r)
     end
-    dz
+    return dz
 end
 
-function relax!(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
-        linesearch) where {TF}
+function relax!(
+        dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
+        linesearch
+    ) where {TF}
     let dz = dz,
-        integrator = integrator,
-        nlsolver = nlsolver,
-        f = f,
-        linesearch = linesearch
+            integrator = integrator,
+            nlsolver = nlsolver,
+            f = f,
+            linesearch = linesearch
 
-        @unpack uprev, t, p, dt, opts, isdae = integrator
-        @unpack z, tmp, ztmp, γ, iter, α, cache, method = nlsolver
-        @unpack ustep, atmp, tstep, k, invγdt = cache
+        (; uprev, t, p, dt, opts, isdae) = integrator
+        (; z, tmp, ztmp, γ, iter, α, cache, method) = nlsolver
+        (; ustep, atmp, tstep, k, invγdt) = cache
         function resid(z)
             # recompute residual (rhs)
             if isdae
                 _uprev = get_dae_uprev(integrator, uprev)
                 b, ustep2 = _compute_rhs!(
-                    tmp, ztmp, ustep, α, tstep, k, invγdt, p, _uprev, f::TF, z)
+                    tmp, ztmp, ustep, α, tstep, k, invγdt, p, _uprev, f::TF, z
+                )
             else
                 b, ustep2 = _compute_rhs!(
-                    tmp, ztmp, ustep, γ, α, tstep, k, invγdt, method, p, dt, f, z)
+                    tmp, ztmp, ustep, γ, α, tstep, k, invγdt, method, p, dt, f, z
+                )
             end
-            calculate_residuals!(atmp, b, uprev, ustep2, opts.abstol, opts.reltol,
-                opts.internalnorm, t)
+            calculate_residuals!(
+                atmp, b, uprev, ustep2, opts.abstol, opts.reltol,
+                opts.internalnorm, t
+            )
             ndz = opts.internalnorm(atmp, t)
             return ndz
         end
@@ -504,30 +546,36 @@ function relax!(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
     end
 end
 
-function relax(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
-        r::Number) where {TF}
+function relax(
+        dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
+        r::Number
+    ) where {TF}
     if !iszero(r)
         dz = (1 - r) * dz
     end
     return dz
 end
 
-function relax(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
-        r::Nothing) where {TF}
+function relax(
+        dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
+        r::Nothing
+    ) where {TF}
     return dz
 end
 
-function relax(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
-        linesearch) where {TF}
+function relax(
+        dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
+        linesearch
+    ) where {TF}
     let dz = dz,
-        integrator = integrator,
-        nlsolver = nlsolver,
-        f = f,
-        linesearch = linesearch
+            integrator = integrator,
+            nlsolver = nlsolver,
+            f = f,
+            linesearch = linesearch
 
-        @unpack uprev, t, p, dt, opts = integrator
-        @unpack z, tmp, ztmp, γ, iter, cache, method = nlsolver
-        @unpack ustep, atmp, tstep, k, invγdt = cache
+        (; uprev, t, p, dt, opts) = integrator
+        (; z, tmp, ztmp, γ, iter, cache, method) = nlsolver
+        (; ustep, atmp, tstep, k, invγdt) = cache
         function resid(z)
             # recompute residual (rhs)
             if f isa DAEFunction
@@ -536,8 +584,10 @@ function relax(dz, nlsolver::AbstractNLSolver, integrator::DEIntegrator, f::TF,
             else
                 ztmp, ustep2 = _compute_rhs(tmp, γ, α, tstep, invγdt, method, p, f, z)
             end
-            atmp = calculate_residuals(b, uprev, ustep2, opts.abstol, opts.reltol,
-                opts.internalnorm, t)
+            atmp = calculate_residuals(
+                b, uprev, ustep2, opts.abstol, opts.reltol,
+                opts.internalnorm, t
+            )
             ndz = opts.internalnorm(atmp, t)
             return ndz
         end
@@ -579,6 +629,5 @@ function Base.resize!(nlcache::NLNewtonCache, ::AbstractNLSolver, integrator, i:
     # resize J and W (or rather create new ones of appropriate size and type)
     resize_J_W!(nlcache, integrator, i)
 
-    nothing
+    return nothing
 end
-
