@@ -3,5 +3,6 @@ using JET
 
 @testset "JET Tests" begin
     test_package(
-        OrdinaryDiffEqNonlinearSolve, target_defined_modules = true, mode = :typo)
-end
\ No newline at end of file
+        OrdinaryDiffEqNonlinearSolve, target_defined_modules = true, mode = :typo
+    )
+end
